==> vtigercrm7.1.0rc.tar.gz: vtigercrm/pkg/vtiger/translations/BritishLanguagePack_br_br/modules/Settings/CustomerPortal.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$languageStrings = array(
	'CustomerPortal'               => 'Customer Portal'             , // TODO: Review
	'LBL_PORTAL_DESCRIPTION'       => 'Setup Privileges of Portal User', // TODO: Review
	'LBL_PRIVILEGES'               => 'Privileges'                  , // TODO: Review
	'LBL_DEFAULT_ASSIGNEE'         => 'Default Assignee'            , // TODO: Review
	'LBL_PORTAL_URL'               => 'Portal Url'                  , // TODO: Review
	'LBL_MODULE_NAME'              => 'Module Name'                 , // TODO: Review
	'LBL_ENABLE_MODULE'            => 'Enable Module'               , // TODO: Review
	'LBL_VIEW_ALL_RECORDS'         => 'See Records across Organization', // TODO: Review
	//Messages
	'LBL_PREVILEGES_MESSAGE' => "This User's privileges will be applied to the Portal User.",
	'LBL_DEFAULT_ASSIGNEE_MESSAGE' => 'Cases/Tickets will be Assigned to the selected Assignee by the default Group/User from the Customer Portal.',
	'LBL_PORTAL_URL_MESSAGE' => 'This is URL for the Portal where your contacts can login to submit/track tickets, access knowledge base and do more.',
    'LBL_CONTACTS_ENABLE_MESSAGE'=>'Contacts will be sent the login details when Portal access is enabled from Contact details page.',
    'LBL_SUPPORT_NOTIFY_MESSAGE'=>'Support contract renewal alert is notified on the customer portal based on the number of days entered.',
	'LBL_DRAG_AND_DROP_MESSAGE' => 'Drag and Drop modules to reorder in the Customer Portal',
    //Portal shortcuts
    'LBL_ADD_DOCUMENT'=>'Add Document',
    'LBL_OPEN_TICKETS'=>'Open Tickets',
    'LBL_CREATE_TICKET'=>'Create Ticket',
    'LBL_ADD_SHORTCUT'=>'Add Shortcut',
    //Charts
    'OpenTicketsByPriority'=>'Open tickets by priority',
    'TicketsClosureTimeByPriority'=>'Tickets closure time by priority',
    'OpenTicketsBySeverity'=>'Open tickets by severity',
    'TicketsClosureTimeBySeverity'=>'Tickets closure time by severity',
    
    'Announcement' => 'Announcement',
    'Activity Stream' => 'Activity Stream',
    'Fields and privilege' => 'Fields and privilege',
    
    //Record visiblity status
    
    'onlymine'=>'Show only  %s  linked to contact',
    'all'=>'Show %s linked to contact and organization',
    "products_or_services"=>"Show all %s",
    "faq"=>"Show all published %s",
    'LBL_LAYOUT_HEADER'=>'Portal Menu',
    'LBL_HOME'=>'Home',
    'LBL_CONTACT_NOTIFACTION'=>'Contact Support Notification',
    'LBL_DAYS_BEFORE'=>'Days before',
    'LBL_HOME_LAYOUT'=>'Portal Home Layout',
    'LBL_RELATED_INFORMATION'=>'Related Information',
    'LBL_RECORD_VISIBILITY'=>'Records Visibility',
    'LBL_ADD_FIELDS'=>'Add Fields',
    'LBL_READ_AND_WRITE'=>'Read and write',
    'LBL_READ_ONLY'=>'Read only',
    'LBL_PORTAL_FIELDS_PRIVILEGES'=>'Portal Fields And Privileges',
    'LBL_RECENT'=>'Recent',
    'LBL_REC_WIDGET'=>'Record Widget',
    'LBL_CHARTS'=>'Charts',
    'LBL_ANNOUNCEMENT'=>'Announcement',
    'LBL_SHORTCUTS'=>'Shortcuts',
    'LBL_SHOW'=>'Visible',
    "History"=>"Updates",
    "LBL_VISIBILITY"=>"Visibility",
    'LBL_RECORD_PERMISSIONS'=>'Record Permissions',
    'LBL_CREATE_RECORD'=>'Create Record',
    'LBL_CREATE_RECORD'=>'Edit Record',

  'LBL_CREATE_CASE' => 'Create Case',
  'LBL_OPEN_CASES' => 'Open Cases',
  'OpenCasesByPriority' => 'Open cases by priority',
  'CasesClosureTimeByPriority' => 'Cases resolution time by priority',
  'LBL_CONTACT_NOTIFICATION' => 'Contact Support Notification',
  'LBL_EDIT_RECORD' => 'Edit Record',

);

$jsLanguageStrings = array(
	'JS_PORTAL_INFO_SAVED' => 'Customer Portal settings saved',
    'LBL_ADD_DOCUMENT'=>'Add Document',
    'LBL_OPEN_TICKETS'=>'Open Tickets',
    'LBL_CREATE_TICKET'=>'Create Ticket',
    'JS_SELECT_SHORTCUT'=>'Select a shortcut',
    'JS_ADD_FIELD'=>'Add fields',
    'JS_SHOW'=>'Visible',
    'JS_HIDE'=>'Hide',
    'JS_NUMBERS'=>"Accepts only positive whole number with upto four digits.",
    'JS_MANDATORY_FIELDS_MISSING'=>'Fields could not be saved.Please select all mandatory fields.'
);

==> vtigercrm8.3.0.tar.gz: vtigercrm/pkg/vtiger/translations/BritishLanguagePack_br_br/modules/Settings/CustomerPortal.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ************************************************************************************/
$languageStrings = array(
	'CustomerPortal'               => 'Customer Portal'             , // TODO: Review
	'LBL_PORTAL_DESCRIPTION'       => 'Setup Privileges of Portal User', // TODO: Review
	'LBL_PRIVILEGES'               => 'Privileges'                  , // TODO: Review
	'LBL_DEFAULT_ASSIGNEE'         => 'Default Assignee'            , // TODO: Review
	'LBL_PORTAL_URL'               => 'Portal Url'                  , // TODO: Review
	'LBL_MODULE_NAME'              => 'Module Name'                 , // TODO: Review
	'LBL_ENABLE_MODULE'            => 'Enable Module'               , // TODO: Review
	'LBL_VIEW_ALL_RECORDS'         => 'See Records across Organization', // TODO: Review
	//Messages
	'LBL_PREVILEGES_MESSAGE' => "This User's privileges will be applied to the Portal User.",
	'LBL_DEFAULT_ASSIGNEE_MESSAGE' => 'Cases/Tickets will be Assigned to the selected Assignee by the default Group/User from the Customer Portal.',
	'LBL_PORTAL_URL_MESSAGE' => 'This is URL for the Portal where your contacts can login to submit/track tickets, access knowledge base and do more.',
    'LBL_CONTACTS_ENABLE_MESSAGE'=>'Contacts will be sent the login details when Portal access is enabled from Contact details page.',
    'LBL_SUPPORT_NOTIFY_MESSAGE'=>'Support contract renewal alert is notified on the customer portal based on the number of days entered.',
	'LBL_DRAG_AND_DROP_MESSAGE' => 'Drag and Drop modules to reorder in the Customer Portal',
    //Portal shortcuts
    'LBL_ADD_DOCUMENT'=>'Add Document',
    'LBL_OPEN_TICKETS'=>'Open Tickets',
    'LBL_CREATE_TICKET'=>'Create Ticket',
    'LBL_ADD_SHORTCUT'=>'Add Shortcut',
    //Charts
    'OpenTicketsByPriority'=>'Open tickets by priority',
    'TicketsClosureTimeByPriority'=>'Tickets closure time by priority',
    'OpenTicketsBySeverity'=>'Open tickets by severity',
    'TicketsClosureTimeBySeverity'=>'Tickets closure time by severity',
    
    'Announcement' => 'Announcement',
    'Activity Stream' => 'Activity Stream',
    'Fields and privilege' => 'Fields and privilege',
    
    //Record visiblity status
    
    'onlymine'=>'Show only  %s  linked to contact',
    'all'=>'Show %s linked to contact and organization',
    "products_or_services"=>"Show all %s",
    "faq"=>"Show all published %s",
    'LBL_LAYOUT_HEADER'=>'Portal Menu',
    'LBL_HOME'=>'Home',
    'LBL_CONTACT_NOTIFACTION'=>'Contact Support Notification',
    'LBL_DAYS_BEFORE'=>'Days before',
    'LBL_HOME_LAYOUT'=>'Portal Home Layout',
    'LBL_RELATED_INFORMATION'=>'Related Information',
    'LBL_RECORD_VISIBILITY'=>'Records Visibility',
    'LBL_ADD_FIELDS'=>'Add Fields',
    'LBL_READ_AND_WRITE'=>'Read and write',
    'LBL_READ_ONLY'=>'Read only',
    'LBL_PORTAL_FIELDS_PRIVILEGES'=>'Portal Fields And Privileges',
    'LBL_RECENT'=>'Recent',
    'LBL_REC_WIDGET'=>'Record Widget',
    'LBL_CHARTS'=>'Charts',
    'LBL_ANNOUNCEMENT'=>'Announcement',
    'LBL_SHORTCUTS'=>'Shortcuts',
    'LBL_SHOW'=>'Visible',
    "History"=>"Updates",
    "LBL_VISIBILITY"=>"Visibility",
    'LBL_RECORD_PERMISSIONS'=>'Record Permissions',
    'LBL_CREATE_RECORD'=>'Create Record',
    'LBL_EDIT_RECORD'=>'Edit Record',

  'LBL_CREATE_CASE' => 'Create Case',
  'LBL_OPEN_CASES' => 'Open Cases',
  'OpenCasesByPriority' => 'Open cases by priority',
  'CasesClosureTimeByPriority' => 'Cases resolution time by priority',
  'LBL_CONTACT_NOTIFICATION' => 'Contact Support Notification',
  'LBL_EDIT_RECORD' => 'Edit Record',

);

$jsLanguageStrings = array(
	'JS_PORTAL_INFO_SAVED' => 'Customer Portal settings saved',
    'LBL_ADD_DOCUMENT'=>'Add Document',
    'LBL_OPEN_TICKETS'=>'Open Tickets',
    'LBL_CREATE_TICKET'=>'Create Ticket',
    'JS_SELECT_SHORTCUT'=>'Select a shortcut',
    'JS_ADD_FIELD'=>'Add fields',
    'JS_SHOW'=>'Visible',
    'JS_HIDE'=>'Hide',
    'JS_NUMBERS'=>"Accepts only positive whole number with upto four digits.",
    'JS_MANDATORY_FIELDS_MISSING'=>'Fields could not be saved.Please select all mandatory fields.'
);
